@@ -13,8 +13,7 @@ class Tool(object):
         self.mail_from_user = ''    # 邮件发送者账号
         self.mail_from_user_pwd = ''    # 邮件发送者密码
         self.mail_from_user_host = ''    # 邮件发送者host
-        
-        # self.qy_wechat_token = ''  # 企业微信机器人token
+        self.qy_wechat_token = ''  # 企业微信机器人token
 
     def send_mail_msg(self, to_user, subject, content):
         send_mail_util(self.mail_from_user, self.mail_from_user_pwd, self.mail_from_user_host, to_user, subject, content)
